"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.keyword = exports.CommentTag = exports.Ident = exports.Space = exports.WordBoundary = void 0;
const pattern_1 = require("./pattern");
const scope_1 = require("./scope");
/**
 * Represents a word boundary.
 */
exports.WordBoundary = (0, pattern_1.regex)('\\b');
/**
 * Represents any space character.
 */
exports.Space = (0, pattern_1.regex)('\\s');
/**
 * An identifier pattern that can start with letters or '_' and continue with
 * alphanumeric characters or '_'.
 */
exports.Ident = (0, pattern_1.regex)('[_[:alpha:]][_[:alnum:]]*');
/**
 * Common tags in comments.
 */
exports.CommentTag = (0, pattern_1.cat)(exports.WordBoundary, (0, pattern_1.or)((0, pattern_1.literal)('TODO'), (0, pattern_1.literal)('FIXME'), (0, pattern_1.literal)('NOTE'), (0, pattern_1.literal)('BUG'), (0, pattern_1.literal)('OPTIMIZE'), (0, pattern_1.literal)('HACK'), (0, pattern_1.literal)('XXX')), 
// Optionally, allow the user tag in parens after, like TODO(LPeter1997)
(0, pattern_1.opt)((0, pattern_1.cat)((0, pattern_1.literal)('('), (0, pattern_1.rep1)((0, pattern_1.regex)('[^(]')).tag(scope_1.Scopes.Comment.TagAuthor), (0, pattern_1.literal)(')'))), 
// Colon required
(0, pattern_1.literal)(':')).tag(scope_1.Scopes.Comment.Tag);
/**
 * Creates a sequence of alternative keywords that are separated by word boundaries.
 * @param kws The possible keywords.
 * @returns The created pattern.
 */
const keyword = (...kws) => (0, pattern_1.cat)(exports.WordBoundary, (0, pattern_1.or)(...kws.map(pattern_1.literal)), exports.WordBoundary);
exports.keyword = keyword;
