"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Language = exports.createLanguage = void 0;
const mode_1 = require("./mode");
/**
 * Creates a new language for highlighting.
 * @param config The language configuration.
 * @returns A newly created language.
 */
function createLanguage(config) {
    return new Language(config);
}
exports.createLanguage = createLanguage;
/**
 * Represents a language description.
 */
class Language {
    constructor(config) {
        this.startModes = [];
        this.modeRepo = new Map();
        this.name = config.name;
        this.scopeName = toKebabCase(this.name);
        this.extensions = config.extensions;
    }
    /**
     * Adds a mode to the language.
     * @param m The mode to add.
     */
    addMode(m) {
        let mode = (0, mode_1.modeDescriptionToMode)(m);
        if ('name' in m)
            this.modeRepo.set(m['name'], mode);
        else
            this.startModes.push(mode);
        return this;
    }
    toTextMate() {
        let repo = {};
        for (let [name, mode] of this.modeRepo)
            repo[name] = mode.toTextMate(this);
        return {
            "$schema": "https://raw.githubusercontent.com/martinring/tmlanguage/master/tmlanguage.json",
            scopeName: this.scopeName,
            fileTypes: this.extensions,
            patterns: this.startModes.map(m => m.toTextMate(this)),
            repository: repo,
        };
    }
}
exports.Language = Language;
function toKebabCase(text) {
    return text
        .toLowerCase()
        .replace(/ /g, '-');
}
