import { IPattern } from './pattern';
import { Scope } from './scope';
/**
 * Constructs an include mode for the grammar.
 * @param name The name of the mode to reference.
 * @returns The constructed include mode.
 */
export declare function include(name: string): Mode;
/**
 * The type of a TextMate grammar.
 */
export declare type TextMateGrammar = {
    /**
     * The name of the language.
     */
    name: string;
    /**
     * The language scope name.
     */
    scopeName?: string;
    /**
     * The valid extensions to the language without the dot.
     */
    extensions: string[];
    /**
     * The top-level modes of the language.
     */
    modes: Mode[];
    /**
     * The mode repository.
     */
    repository?: Record<string, Mode | Mode[]>;
};
/**
 * The different highlight modes.
 */
export declare type Mode = {
    scope?: Scope;
    match: IPattern;
    captures?: Record<string, CaptureValue>;
    contains?: Mode[];
} | {
    scope?: Scope;
    begin: IPattern;
    end: IPattern;
    beginCaptures?: Record<string, CaptureValue>;
    endCaptures?: Record<string, CaptureValue>;
    contains?: Mode[];
} | {
    contains: Mode[];
} | {
    include: string;
} | IPattern;
declare type CaptureValue = Mode | Scope;
/**
 * Converts the given TextMate grammar into a JSON object.
 * @param g The TextMate grammar to convert.
 * @returns The converted JSON grammar.
 */
export declare function toTextMate(g: TextMateGrammar): object;
export {};
